#!/bin/bash



# ==============================================================================
# Configuration
# ==============================================================================

minversion="10.4.1"
CWROOT="/usr/local/curbywall"
BIN="/usr/sbin"
DMNROOT="/Library/LaunchDaemons"
CONFROOT="/etc"
execfiles=( "curbywall" "ipfw-status" )
inertfiles=( "ipfw.conf" "local.conf.sample" "routing.conf.sample" "shaping.conf.sample" "local.conf.m4.sample" "README" "COPYING" "CHANGELOG" )



# ==============================================================================
# Sanity Checks
# ==============================================================================

# Check platform
if [[ "`sw_vers -productVersion`" < $minversion ]]; then
  echo "This firewall makes use of features new in OS X $minversion.  If you think you know better,"
  echo "disable this check or install the files manually."
  exit 1
fi

# Check permissions
if [[ "$UID" != "0" ]]; then
  echo "No root privileges detected.  Attempting \`sudo $0\`..."
  sudo $0
  exit
fi



# ==============================================================================
# Uninstall old version
# ==============================================================================

./uninstall.sh
echo



# ==============================================================================
# Install current version
# ==============================================================================

# Make curbywall directory
echo "Making $CWROOT directory..."
install -d -m 755 -g wheel "$CWROOT"

# Install executables and their symlinks
echo "Install 1/3: main files and symlinks"
for file in "${execfiles[@]}"; do
  install -m 755 -g wheel "$file" "$CWROOT"
  echo "$CWROOT/$file" >> "$CWROOT/install.log"
  ln -s "$CWROOT/$file" "$BIN/$file"
  echo "$BIN/$file" >> "$CWROOT/install.log"
done

# Install non-executables
for file in "${inertfiles[@]}"; do
  install -m 644 -g wheel "$file" "$CWROOT"
  echo "$CWROOT/$file" >> "$CWROOT/install.log"
done

# Install sysctl file
echo -n "Install 2/3: sysctl.conf"
if [[ -e "/etc/sysctl.conf" ]]; then
  old_md5=$(md5sum /etc/sysctl.conf | awk '{print $1}')
  new_md5=$(md5sum sysctl.conf | awk '{print $1}')
  if [[ "$old_md5" != "$new_md5" ]]; then
    echo ": file exists, will overwrite (with backup)"
    install -b -m 644 -g wheel "sysctl.conf" "$CONFROOT"
  else
    echo ": already installed, will skip"
  fi
else
  echo
  install -b -m 644 -g wheel "sysctl.conf" "$CONFROOT"
fi
# The installation/uninstallation of sysctl must be handled carefully.
# Since other things can use it and modify it, we don't auto-uninstall
#echo "$CONFROOT/sysctl.conf" >> "$CWROOT/install.log"

# Install LaunchDaemon
echo "Install 3/3: LaunchDaemon"
install -m 644 -g wheel "net.curby.Curbywall.plist" "$DMNROOT"
echo "$DMNROOT/net.curby.Curbywall.plist" >> "$CWROOT/install.log"

# Remember to uninstall the uninstall log and our directory
echo "$CWROOT/install.log" >> "$CWROOT/install.log"
echo "$CWROOT" >> "$CWROOT/install.log"



# ==============================================================================
# Miscellaneous System Configuration
# ==============================================================================

# Enable logging both for reboots and now
echo "Enabling verbose logging..."
defaults write "/Library/Preferences/com.apple.sharing.firewall" loggingenabled -integer '1'
sysctl -w net.inet.ip.fw.verbose=2 > /dev/null

# XXX check for and handle default local ruleset

echo
echo "Installation completed.  Run curbywall to initialize firewall."
